==> openvkl-2.0.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/openvkl-2.0.0/openvklConfig.cmake <==
## Copyright 2019 Intel Corporation
## SPDX-License-Identifier: Apache-2.0


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was openvklConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/rkcommon" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

## Include openvkl targets ##

include("${CMAKE_CURRENT_LIST_DIR}/openvkl_Exports.cmake")

check_required_components("openvkl")

## openvkl ISA build configuration ##

set(OPENVKL_ISA_SSE4 )
set(OPENVKL_ISA_AVX )
set(OPENVKL_ISA_AVX2 )
set(OPENVKL_ISA_AVX512KNL )
set(OPENVKL_ISA_AVX512SKX )
set(OPENVKL_ISA_NEON ON)
set(OPENVKL_ISA_NEON2X OFF)

## Standard signal that the package was found ##

set(openvkl_FOUND TRUE)

## Dependencies

# Assume this file is in "lib/cmake/openvkl-*/", and form the install root
set(OPENVKL_ROOT ${CMAKE_CURRENT_LIST_DIR}/../../..)

# Setup library path vars
if (WIN32)
  set(LIBRARY_PATH_PREFIX ${OPENVKL_ROOT}//usr/lib/${CMAKE_IMPORT_LIBRARY_PREFIX})
else()
  set(LIBRARY_PATH_PREFIX ${OPENVKL_ROOT}//usr/lib/${CMAKE_SHARED_LIBRARY_PREFIX})
endif()

# only needed for GPU device
if (TARGET openvkl::openvkl_module_gpu_device)

  if (WIN32)
    set(LIB_SUFFIX lib)
  else()
    # on other platforms need to handle libs like librkcommon.so.1
    set(LIB_SUFFIX *)
  endif()

  if (TARGET rkcommon::rkcommon)
    set(RKCOMMON_LIBRARY rkcommon::rkcommon)
  else()
    file(GLOB_RECURSE RKCOMMON_LIBRARY ${LIBRARY_PATH_PREFIX}rkcommon*.${LIB_SUFFIX})
  endif()

  if (TARGET ispcrt::ispcrt)
    set(ISPCRT_LIBRARY ispcrt::ispcrt)
  else()
    file(GLOB_RECURSE ISPCRT_LIBRARY ${LIBRARY_PATH_PREFIX}ispcrt.${LIB_SUFFIX})
  endif()

  if (TARGET embree)
    set(EMBREE_LIBRARY embree)
  else()
    file(GLOB_RECURSE EMBREE_LIBRARY ${LIBRARY_PATH_PREFIX}embree*.${LIB_SUFFIX})
  endif()

  if (TARGET TBB::tbb AND TARGET TBB::tbbmalloc)
    set (TBB_LIBRARY TBB::tbb TBB::tbbmalloc)
  else()
    file(GLOB_RECURSE TBB_LIBRARY ${LIBRARY_PATH_PREFIX}tbb.${LIB_SUFFIX})
  endif()

  # Add missing targets to libraries
  set_target_properties(openvkl::openvkl_module_gpu_device PROPERTIES
    INTERFACE_LINK_LIBRARIES "${RKCOMMON_LIBRARY};${ISPCRT_LIBRARY};${EMBREE_LIBRARY};${TBB_LIBRARY}"
  )

endif()

==> openvkl-2.0.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/openvkl-2.0.1/openvklConfig.cmake <==
## Copyright 2019 Intel Corporation
## SPDX-License-Identifier: Apache-2.0


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was openvklConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/rkcommon" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

## Include openvkl targets ##

include("${CMAKE_CURRENT_LIST_DIR}/openvkl_Exports.cmake")

check_required_components("openvkl")

## openvkl ISA build configuration ##

set(OPENVKL_ISA_SSE4 )
set(OPENVKL_ISA_AVX )
set(OPENVKL_ISA_AVX2 )
set(OPENVKL_ISA_AVX512KNL )
set(OPENVKL_ISA_AVX512SKX )
set(OPENVKL_ISA_NEON ON)
set(OPENVKL_ISA_NEON2X OFF)

## Standard signal that the package was found ##

set(openvkl_FOUND TRUE)

## Dependencies

# Assume this file is in "lib/cmake/openvkl-*/", and form the install root
set(OPENVKL_ROOT ${CMAKE_CURRENT_LIST_DIR}/../../..)

# Setup library path vars
if (WIN32)
  set(LIBRARY_PATH_PREFIX ${OPENVKL_ROOT}/lib/${CMAKE_IMPORT_LIBRARY_PREFIX})
else()
  set(LIBRARY_PATH_PREFIX ${OPENVKL_ROOT}/lib/${CMAKE_SHARED_LIBRARY_PREFIX})
endif()

# only needed for GPU device
if (TARGET openvkl::openvkl_module_gpu_device)

  if (WIN32)
    set(LIB_SUFFIX lib)
  else()
    # on other platforms need to handle libs like librkcommon.so.1
    set(LIB_SUFFIX *)
  endif()

  if (TARGET rkcommon::rkcommon)
    set(RKCOMMON_LIBRARY rkcommon::rkcommon)
  else()
    file(GLOB_RECURSE RKCOMMON_LIBRARY ${LIBRARY_PATH_PREFIX}rkcommon*.${LIB_SUFFIX})
  endif()

  if (TARGET embree)
    set(EMBREE_LIBRARY embree)
  else()
    file(GLOB_RECURSE EMBREE_LIBRARY ${LIBRARY_PATH_PREFIX}embree*.${LIB_SUFFIX})
  endif()

  if (TARGET TBB::tbb AND TARGET TBB::tbbmalloc)
    set (TBB_LIBRARY TBB::tbb TBB::tbbmalloc)
  else()
    file(GLOB_RECURSE TBB_LIBRARY ${LIBRARY_PATH_PREFIX}tbb.${LIB_SUFFIX})
  endif()

  # Add missing targets to libraries
  set_target_properties(openvkl::openvkl_module_gpu_device PROPERTIES
    INTERFACE_LINK_LIBRARIES "${RKCOMMON_LIBRARY};${EMBREE_LIBRARY};${TBB_LIBRARY}"
  )

endif()
